<?php
namespace App\Http\Controllers\API;

use App\Http\Resources\UserResource;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;

use App\Http\Controllers\Auth\AuthenticatedSessionController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/


Route::post('register', [AuthAPIController::class, 'register']);
Route::post('trainer_register', [AuthAPIController::class, 'trainer_register']);
Route::post('login', [AuthAPIController::class, 'login']);
Route::post('login_email', [AuthAPIController::class, 'login_email']);
Route::post('phone_verify', [AuthAPIController::class, 'phone_verify']);
Route::post('phone_otp_verify', [AuthAPIController::class, 'phone_otp_verify']);
Route::post('forget_password', [AuthAPIController::class, 'forget_password']);
Route::post('password_phone_otp', [AuthAPIController::class, 'password_phone_otp']);
Route::post('password_reset', [AuthAPIController::class, 'password_reset']);
Route::post('change_password', [AuthAPIController::class, 'change_password'])->middleware(['auth:sanctum']);
Route::get('get_profile', [AuthAPIController::class, 'get_profile'])->middleware(['auth:sanctum']);
Route::post('update_profile', [AuthAPIController::class, 'update_profile'])->middleware(['auth:sanctum']);
Route::post('social_login', [AuthAPIController::class, 'social_login']);
Route::post('logout', [AuthAPIController::class, 'logout'])->middleware(['auth:sanctum']);
Route::post('delete_account', [AuthAPIController::class, 'delete_account'])->middleware(['auth:sanctum']);
Route::post('delete_logo', [AuthAPIController::class, 'delete_logo'])->middleware(['auth:sanctum']);
Route::post('update_device_token', [AuthAPIController::class, 'update_device_token'])->middleware(['auth:sanctum']);
Route::post('update_user_levels', [AuthAPIController::class, 'update_user_levels'])->middleware(['auth:sanctum']);
Route::post('update_user_online', [AuthAPIController::class, 'update_user_online'])->middleware(['auth:sanctum']);

Route::post('verify', [AuthAPIController::class, 'verify']);

Route::get('my_subscription', [AuthAPIController::class, 'my_subscription'])->middleware(['auth:sanctum']);

Route::middleware(['auth:sanctum'])->get('/user', function (Request $request) {
    return new UserResource($request->user());
});

Route::resource('sliders', SliderAPIController::class)
    ->except(['create', 'edit']);
Route::put('/sliders/{id}/activateToggle', [SliderAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('intro_pages', IntroPageAPIController::class)
    ->except(['create', 'edit']);
Route::put('/intro_pages/{id}/activateToggle', [IntroPageAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('countries', CountryAPIController::class)
    ->except(['create', 'edit']);
Route::put('/countries/{id}/activateToggle', [CountryAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('cities', CityAPIController::class)
    ->except(['create', 'edit']);
Route::put('/cities/{id}/activateToggle', [CityAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('regions', RegionAPIController::class)
    ->except(['create', 'edit']);
Route::put('/regions/{id}/activateToggle', [RegionAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('packages', PackageAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::put('/packages/{id}/activateToggle', [PackageAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);
Route::get('/my_package', [PackageAPIController::class, 'my_package'])->middleware(['auth:sanctum']);
Route::post('/subscribe_package', [PackageAPIController::class, 'subscribe_package'])->middleware(['auth:sanctum']);

Route::resource('training_types', TrainingTypeAPIController::class)
    ->except(['create', 'edit']);
Route::put('/training_types/{id}/activateToggle', [TrainingTypeAPIController::class, 'activateToggle']);
Route::get('/training_types_tree', [TrainingTypeAPIController::class, 'training_types_tree']);



Route::resource('type_levels', TypeLevelAPIController::class)
    ->except(['create', 'edit']);
Route::put('/type_levels/{id}/activateToggle', [TypeLevelAPIController::class, 'activateToggle']);

Route::resource('level_categories', LevelCategoryAPIController::class)
    ->except(['create', 'edit']);
Route::put('/level_categories/{id}/activateToggle', [LevelCategoryAPIController::class, 'activateToggle']);

Route::resource('users', UserAPIController::class)
    ->except(['create', 'edit']);
Route::put('/users/{id}/activateToggle', [UserAPIController::class, 'activateToggle']);
Route::post('/change_user_password/{id}', [UserAPIController::class, 'change_user_password'])->middleware(['auth:sanctum']);
Route::post('/users_multi_delete', [UserAPIController::class, 'multi_delete']);

Route::resource('questions', QuestionAPIController::class)
    ->except(['create', 'edit']);
Route::put('/questions/{id}/activateToggle', [QuestionAPIController::class, 'activateToggle']);
Route::post('/questions_multi_delete', [QuestionAPIController::class, 'multi_delete']);

Route::resource('question_types', QuestionTypeAPIController::class)
    ->except(['create', 'edit']);
Route::put('/question_types/{id}/activateToggle', [QuestionTypeAPIController::class, 'activateToggle']);

Route::resource('trainings', TrainingAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::put('/trainings/{id}/activateToggle', [TrainingAPIController::class, 'activateToggle']);
Route::put('/trainings/{id}/collectStudentPoints', [TrainingAPIController::class, 'collectStudentPoints'])->middleware(['auth:sanctum']);
Route::post('add_training_by_trainer_for_students', [TrainingAPIController::class, 'add_training_by_trainer_for_students'])->middleware(['auth:sanctum']);
Route::post('share_training_by_trainer_for_students/{id}', [TrainingAPIController::class, 'share_training_by_trainer_for_students'])->middleware(['auth:sanctum']);

Route::resource('competitions', CompetitionAPIController::class)->middleware(['auth:sanctum']);
Route::resource('competition_subscribers', CompetitionSubscriberAPIController::class)->middleware(['auth:sanctum']);
Route::post('add_competition_result_to_subscriber', [CompetitionSubscriberAPIController::class, 'add_competition_result_to_subscriber'])->middleware(['auth:sanctum']);
Route::post('/competitions/collectStudentPoints', [CompetitionSubscriberAPIController::class, 'collectStudentPoints'])->middleware(['auth:sanctum']);
Route::resource('competition_messages', CompetitionMessageAPIController::class)->middleware(['auth:sanctum']);
Route::get('competition_levels', [TypeLevelAPIController::class, 'competition'])->middleware(['auth:sanctum']);

Route::get('my_competitions', [CompetitionAPIController::class, 'my_competitions'])->middleware(['auth:sanctum']);
Route::post('share_competition_for_subscribers/{id}', [CompetitionAPIController::class, 'share_competition_for_subscribers'])->middleware(['auth:sanctum']);

Route::put('/competition_subscribers/{id}/activateToggle', [CompetitionSubscriberAPIController::class, 'activateToggle']);

Route::resource('home', HomeController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);

Route::get('/myTrainings', [HomeController::class, 'myTrainings'])->middleware(['auth:sanctum']);


Route::resource('subscriptions', SubscriptionAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);

Route::get('friends', [FavouritesController::class, 'index'])->middleware(['auth:sanctum']);
Route::post('friend/{id}', [FavouritesController::class, 'favourite'])->middleware(['auth:sanctum']);
Route::post('add_friend/{id}', [FavouritesController::class, 'favourite'])->middleware(['auth:sanctum']);
Route::post('delete_friend/{id}', [FavouritesController::class, 'favourite'])->middleware(['auth:sanctum']);
Route::post('accept_friend_request', [FavouritesController::class, 'accept_friend_request'])->middleware(['auth:sanctum']);

Route::post('multiple_special_students', [FavouritesController::class, 'multiple_special_students'])->middleware(['auth:sanctum']);


Route::resource('trainers', TrainerAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::put('/trainers/{id}/specialToggle', [TrainerAPIController::class, 'specialToggle']);

Route::resource('students', StudentAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::get('statistics/{id}', [StudentAPIController::class, 'statistics'])->middleware(['auth:sanctum']);
Route::get('friends/{id}', [StudentAPIController::class, 'friends'])->middleware(['auth:sanctum']);
Route::get('levels/{id}', [StudentAPIController::class, 'levels'])->middleware(['auth:sanctum']);

Route::resource('trainer_regions', TrainerRegionAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('trainer_galleries', TrainerGalleryAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('trainer_reviews', TrainerReviewAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('chat_messages', TrainerMessageAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);

Route::get('chat', [TrainerMessageAPIController::class, 'chat'])->middleware(['auth:sanctum']);



Route::resource('age_categories', AgeCategoryAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('championships', ChampionshipAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('championship_messages', ChampionshipMessageAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::resource('championship_subscribers', ChampionshipSubscriberAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::put('/championships/{id}/activateToggle', [ChampionshipAPIController::class, 'activateToggle']);
Route::get('my_champions', [ChampionshipAPIController::class, 'my_champions'])->middleware(['auth:sanctum']);
Route::get('certificates', [ChampionshipAPIController::class, 'certificates'])->middleware(['auth:sanctum']);
Route::get('certificates/{id}', [ChampionshipAPIController::class, 'certificate'])->middleware(['auth:sanctum']);

Route::put('/championship_subscribers/{id}/activateToggle', [ChampionshipSubscriberAPIController::class, 'activateToggle']);


Route::post('add_championship_result_to_subscriber', [ChampionshipSubscriberAPIController::class, 'add_championship_result_to_subscriber'])->middleware(['auth:sanctum']);
Route::post('/championships/collectStudentPoints', [ChampionshipSubscriberAPIController::class, 'collectStudentPoints'])->middleware(['auth:sanctum']);
Route::get('championship_levels', [TypeLevelAPIController::class, 'championship'])->middleware(['auth:sanctum']);
Route::post('update_championship_levels/{id}', [ChampionshipAPIController::class, 'update_championship_levels'])->middleware(['auth:sanctum']);
Route::post('add_level_exam', [ChampionshipAPIController::class, 'add_level_exam'])->middleware(['auth:sanctum']);
Route::post('add_levels_exams', [ChampionshipAPIController::class, 'add_levels_exams'])->middleware(['auth:sanctum']);
Route::post('answer_championship_questions', [ChampionshipAPIController::class, 'answer_championship_questions'])->middleware(['auth:sanctum']);
Route::post('/notify_championship_subscribers', [ChampionshipSubscriberAPIController::class, 'notify_championship_subscribers'])->middleware(['auth:sanctum']);

Route::get('start_championship/{id}', [ChampionshipAPIController::class, 'start_championship'])->middleware(['auth:sanctum']);
Route::post('finish_championship/{id}', [ChampionshipAPIController::class, 'finish_championship']);
Route::get('personal_levels', [TypeLevelAPIController::class, 'personal_levels'])->middleware(['auth:sanctum']);


Route::resource('coupons', CouponAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
Route::put('/coupons/{id}/activateToggle', [CouponAPIController::class, 'activateToggle']);
Route::post('apply_coupon', [CouponAPIController::class, 'apply_coupon']);

Route::resource('contact_us', ContactAPIController::class)
    ->except(['create', 'edit']);

Route::resource('pages', PageAPIController::class)
    ->except(['create', 'edit']);

Route::resource('notifications', NotificationApiController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
    
Route::get('show_all_notifications', [NotificationApiController::class, 'show_all'])->middleware(['auth:sanctum']);
    
Route::get('notification_action_done/{id}', [NotificationApiController::class, 'is_action_done'])->middleware(['auth:sanctum']);

Route::get('statistics', [AuthAPIController::class, 'statistics'])->middleware(['auth:sanctum']);


Route::resource('settings', SettingController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);


Route::get('download', [ChampionshipAPIController::class, 'download']);

Route::get('get_all_permissions', [DashController::class, 'get_all_permissions'])->middleware(['auth:sanctum']);

Route::resource('dash', DashController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);

Route::get('last_championship_winners_subscribers', [DashController::class, 'last_championship_winners_subscribers'])->middleware(['auth:sanctum']);

Route::get('last_login_users', [DashController::class, 'last_login_users'])->middleware(['auth:sanctum']);

Route::get('most_students', [DashController::class, 'most_students'])->middleware(['auth:sanctum']);
Route::get('subscription_students', [DashController::class, 'subscription_students'])->middleware(['auth:sanctum']);
Route::get('most_trainings_students', [DashController::class, 'most_trainings_students'])->middleware(['auth:sanctum']);
Route::get('subscription_trainers', [DashController::class, 'subscription_trainers'])->middleware(['auth:sanctum']);


Route::get('attendence_chart', [DashController::class, 'attendence_chart'])->middleware(['auth:sanctum']);


Route::post('answer_question_training', [TrainingAPIController::class, 'answer_question_training'])->middleware(['auth:sanctum']);
Route::get('training_questions_answers', [TrainingAPIController::class, 'training_questions_answers'])->middleware(['auth:sanctum']);
Route::post('answer_training_questions', [TrainingAPIController::class, 'answer_training_questions'])->middleware(['auth:sanctum']);

Route::post('answer_question_competition', [CompetitionAPIController::class, 'answer_question_competition'])->middleware(['auth:sanctum']);
Route::get('competition_questions_answers', [CompetitionAPIController::class, 'competition_questions_answers'])->middleware(['auth:sanctum']);
Route::post('answer_competition_questions', [CompetitionAPIController::class, 'answer_competition_questions'])->middleware(['auth:sanctum']);
Route::put('/competitions/{id}/activateToggle', [CompetitionAPIController::class, 'activateToggle'])->middleware(['auth:sanctum']);

Route::resource('point_levels', PointLevelAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);

Route::resource('admin_notifications', AdminNotificationAPIController::class)
    ->except(['create', 'edit'])->middleware(['auth:sanctum']);
